@@ -216,7 +216,7 @@ kobo_exports <- function(url="kobo.humanitarianresponse.info", uname="", pwd="",
 #' @param pwd is the password of the account
 #' @param assetid is the id of the asset for which the export is to be created
 #' @param all takes logical value in string format. Used to specify whether fields from all form versions will be included in the export.Acceptable values are "true" or "false". Default value is "false".
-#' @param lang takes the language. For e.g. "English (en)".
+#' @param lang takes the language. For e.g. "English (en)". For "XML Values as headers", use '_xml'.
 #' @param hierarchy takes logical value in string format. Used to specify whether the group hierarchy will be displayed in labels. Acceptable values are "true" or "false". Default value is "false".
 #' @param grp_sep is the group separator. Default value is "/".
 #' @param include_grp defines whether or not to include groups. Default value is "true".
@@ -279,7 +279,7 @@ kobo_export_create <- function(url="kobo.humanitarianresponse.info", uname="", p
 #' @param pwd is the password of the account
 #' @param assetid is the id of the asset for which the export is to be created
 #' @param all takes logical value in string format. Used to specify whether fields from all form versions will be included in the export.Acceptable values are "true" or "false". Default value is "false".
-#' @param lang takes the language. For e.g. "English (en)".
+#' @param lang takes the language. For e.g. "English (en)". For "XML Values as headers", use '_xml'.
 #' @param hierarchy takes logical value in string format. Used to specify whether the group hierarchy will be displayed in labels. Acceptable values are "true" or "false". Default value is "false".
 #' @param grp_sep is the group separator. Default value is "/".
 #' @param include_grp defines whether or not to include groups. Default value is "true".
@@ -336,3 +336,125 @@ kobo_df_download <- function(url="kobo.humanitarianresponse.info", uname="", pwd
 
 }
 
+
+#'  Downloads media data from Kobotoolbox
+#'
+#'@description
+#' `kobo_media_downloader` downloads media from data downloaded using `kobo_df_download`. Loops through media columns and downloads files individually.`
+#'
+#'@details
+#' The function creates an export of survey data in 'csv'. If successful, it attempts to download the data and and return a data frame.
+#'
+#' @param url The `[url]` of kobotoolbox Default is "kobo.humanitarianresponse.info".
+#' @param uname is username of your kobotoolbox account
+#' @param pwd is the password of the account
+#' @param assetid is the id of the asset for which the export is to be created
+#' @param fsep is the separator of the downloaded csv file. In most of the cases, it is ";", which is the default. However,
+#' @param sleep is the sleep time between API actions. For example, it takes time to download an export. But R does not wait for the download to finish before going to next step. Hence the need to provide a break between consecutive API actions. Default value is 2 (seconds).
+#' @param identifier is the key using with the columns with URL is identified. Default value is "URL" because in most of the cases, the columns
+#' containing the URL values end with "URL". Please note that any other column name with similar value may cause error.
+#' @param timeoutval is the timeout value in seconds to download the media files. Default is 300 seconds.
+#' @param destfolder is the folder where the media is to be stored.
+#'
+#' @return The function returns a data frame of data downloaded from 'Kobotoolbox'.
+#'
+#'
+#' @importFrom httr POST content authenticate progress DELETE GET
+#' @importFrom jsonlite fromJSON
+#' @importFrom utils read.csv download.file
+#'
+#' @export
+
+kobo_media_downloader <- function(url="kobo.humanitarianresponse.info",uname,pwd, assetid, fsep=";", sleep=2, identifier="URL", timeoutval=300, destfolder="media"){
+  dat<-kobo_df_download(url=url,uname = uname,
+                   pwd=pwd, assetid = assetid,
+                   lang = "_default", sleep=sleep, fsep=fsep)
+
+  print("Please note that this function loops over the URLs and downloads the individual files. This process can be slow and
+        some files may fail to download due to timeout issues. Downloading a zipped file is not supported using API, yet in Kobotoolbox.")
+
+  cnamesdat<-colnames(dat)
+
+  urlcols<-cnamesdat[grepl(paste0("*",identifier),cnamesdat)]
+  options(timeout = max(timeoutval, getOption("timeout")))
+
+  if (!file.exists(destfolder)){
+    dir.create(destfolder)
+  }
+
+  for(i in 1:length(urlcols)){
+    fname<-paste0("./",destfolder,"/",urlcols[i],"_",seq(1:length(dat[,urlcols[i]])))
+    download.file(dat[,urlcols[i]],fname, method="libcurl")
+  }
+
+  return(TRUE)
+
+}
+
+#'  Downloads data (xls type) from Kobotoolbox
+#'
+#'@description
+#' `kobo_xls_dl` is a wrapper for kobotoolbox API `https://[url]/exports/..`
+#'
+#'@details
+#' The function creates an export of survey data in 'xls'. If successful, it attempts to download the data and and return a data frame (reading using `readxl::read_excel`).
+#'
+#' @param url The `[url]` of kobotoolbox Default is "kobo.humanitarianresponse.info".
+#' @param uname is username of your kobotoolbox account
+#' @param pwd is the password of the account
+#' @param assetid is the id of the asset for which the export is to be created
+#' @param all takes logical value in string format. Used to specify whether fields from all form versions will be included in the export.Acceptable values are "true" or "false". Default value is "false".
+#' @param lang takes the language. For e.g. "English (en)". For "XML Values as headers", use '_xml'.
+#' @param hierarchy takes logical value in string format. Used to specify whether the group hierarchy will be displayed in labels. Acceptable values are "true" or "false". Default value is "false".
+#' @param grp_sep is the group separator. Default value is "/".
+#' @param include_grp defines whether or not to include groups. Default value is "true".
+#' @param multi_sel is used to specify the display of multiple_select-type responses. Valid inputs include "both", "summary" or "details". Default is "both".
+#' @param fields is an array of column names to be included in the export (including their group hierarchy). Valid inputs include:
+#' An array containing any string value that matches the XML column name,
+#' An empty array which will result in all columns being included,
+#' If "fields" is not included in the "export_settings", all columns will be included in the export
+#'
+#' @param media_url This will include an additional column for media-type questions ("question_name_URL") with the URL link to the hosted file. Valid inputs are "true" or "false". Default value is true.
+#' @param sub_ids is an array of submission ids that will filter exported submissions to only the specified array of ids. Valid inputs include an array containing integer values or an empty array.
+#' @param sleep is the sleep time between API actions. For example, it takes time to download an export. But R does not wait for the download to finish before going to next step. Hence the need to provide a break between consecutive API actions. Default value is 2 (seconds).
+#'
+#' @return The function returns a data frame of data downloaded from 'Kobotoolbox'.
+#'
+#'
+#' @importFrom httr POST content authenticate progress DELETE GET
+#' @importFrom jsonlite fromJSON
+#' @importFrom utils read.csv
+#' @importFrom readxl read_excel
+#'
+#' @export
+kobo_xls_dl<- function(url="kobo.humanitarianresponse.info", uname="", pwd="",
+                       assetid="", all="false", lang="_default",
+                       hierarchy="false", include_grp="true",grp_sep="/",
+                       multi_sel="both", media_url="true", fields=NULL, sub_ids=NULL, sleep=2){
+
+  new_export_details<-export_creator(url=url, uname=uname, pwd=pwd,
+                                     assetid=assetid, type= "xls", all=all, lang=lang,
+                                     hierarchy=hierarchy, include_grp=include_grp,grp_sep=grp_sep,
+                                     multi_sel=multi_sel, fields=fields, media_url=media_url, sub_ids=sub_ids, sleep=sleep)
+
+  Sys.sleep(sleep)
+
+  if(is.null(new_export_details)){
+    print("export creation was not successful")
+    return(NULL)
+  } else{
+    dff<-export_downloader(new_export_details[[1]], uname=uname, pwd=pwd, sleep=sleep, type="xls")
+    deleteact<-DELETE(url=paste0(url,"/api/v2/assets/",assetid,"/exports/",new_export_details[[2]],"/"),
+                      authenticate(user=uname, password = pwd), progress())
+    while(is.na(deleteact$status_code) | is.null(deleteact$status_code)){
+      print("Attempting export deletion \n")
+    }
+    warn_for_status(deleteact,"delete export. Please delete manually.")
+    if(deleteact$status_code==204) print("Export deleted from server")
+    return(dff)
+  }
+
+
+}
+
+
