@@ -5,7 +5,7 @@ test_that("csv export creation works", {
   x<-kobo_export_create(uname = "scary_scarecrow",
                         pwd="sybWE6USkFxDsr4", assetid = "ahwQoXtnbQJBXCGU24aTao",
                         type = "csv", lang = "English (en)")
-  expect_true( is.character(x) | is.null(x))
+  expect_true( is.character(x))
 })
 
 test_that("geojson export creation works", {
@@ -13,7 +13,7 @@ test_that("geojson export creation works", {
   x<-kobo_export_create(uname = "scary_scarecrow",
                         pwd="sybWE6USkFxDsr4", assetid = "ahwQoXtnbQJBXCGU24aTao",
                         type = "geojson", lang = "English (en)")
-  expect_true( is.character(x)| is.null(x))
+  expect_true(is.character(x))
 })
 
 test_that("xls export creation works", {
@@ -21,7 +21,7 @@ test_that("xls export creation works", {
   x<-kobo_export_create(uname = "scary_scarecrow",
                         pwd="sybWE6USkFxDsr4", assetid = "ahwQoXtnbQJBXCGU24aTao",
                         type = "xls", lang = "English (en)")
-  expect_true( is.character(x) | is.null(x))
+  expect_true( is.character(x))
 })
 
 
@@ -30,7 +30,7 @@ test_that("spss_labels export creation works", {
   x<-kobo_export_create(uname = "scary_scarecrow",
                         pwd="sybWE6USkFxDsr4", assetid = "ahwQoXtnbQJBXCGU24aTao",
                         type = "spss_labels", lang = "English (en)")
-  expect_true( is.character(x) | is.null(x))
+  expect_true( is.character(x))
 })
 
 test_that("invalid export throws error", {
